ALTER TABLE rt_alarm_matching_info ADD COLUMN vms_user_id text;

CREATE TABLE IF NOT EXISTS alive_monitoring_info
(
    alive_monitoring_info_id bigserial NOT NULL,
    ip_address character varying(39) COLLATE pg_catalog."default" NOT NULL,
    port character varying(100) COLLATE pg_catalog."default" NOT NULL,
    node_type smallint NOT NULL,
    node_no smallint NOT NULL,
    node_br_no smallint NOT NULL,
    server_state smallint NOT NULL DEFAULT 0,
    unavailable_flg smallint NOT NULL DEFAULT 0,
    last_communication_datetime timestamp(6) without time zone NOT NULL,
    delete_flg smallint NOT NULL DEFAULT 0,
    create_user character varying(255) COLLATE pg_catalog."default" NOT NULL,
    create_datetime timestamp(6) without time zone NOT NULL,
    update_user character varying(255) COLLATE pg_catalog."default" NOT NULL,
    update_datetime timestamp(6) without time zone NOT NULL,
    CONSTRAINT alive_monitoring_info_pkey PRIMARY KEY (alive_monitoring_info_id)
)
WITH (
    OIDS = FALSE
)
TABLESPACE pg_default;

ALTER TABLE alive_monitoring_info
    OWNER to "OMM_USER";


CREATE OR REPLACE FUNCTION age_and_sex_statistical_info_insert_trigger() RETURNS TRIGGER AS
$$
	DECLARE
		parent text := 'age_and_sex_statistical_info';
		part text;
		t_cur timestamp;
		t_beg timestamp;
		t_end timestamp;
	BEGIN
		part := parent || '_' || to_char(new.aggregation_date, 'YYMM');

		IF NOT EXISTS (
			select * from information_schema.tables
			where table_name = part
		) THEN
			t_cur := new.aggregation_date;
			t_beg := to_timestamp(to_char(t_cur, 'YYYY-MM-01'),
			'YYYY-MM-DD');
			t_end := t_beg + '1 months';

			EXECUTE 'CREATE TABLE ' ||part|| ' (LIKE ' ||parent|| '
		    	INCLUDING INDEXES INCLUDING DEFAULTS INCLUDING CONSTRAINTS, ' ||
				 'CHECK (' ||quote_literal(t_beg)|| ' <= aggregation_date AND aggregation_date < '
		    	|| quote_literal(t_end)|| ')'
				|| ') INHERITS (' ||parent|| ')';

			EXECUTE 'ALTER TABLE ' || part || ' SET (autovacuum_enabled = true, toast.autovacuum_enabled = true)';
		END IF;
		EXECUTE 'INSERT INTO ' || part || ' VALUES(($1).*)' USING new;
		RETURN NULL;
	EXCEPTION WHEN duplicate_table THEN
		EXECUTE 'INSERT INTO ' || part || ' VALUES(($1).*)' USING new;
		RETURN NULL;
    END
$$ language plpgsql;


DROP TRIGGER IF EXISTS age_and_sex_statistical_info_insert_trigger_instance ON age_and_sex_statistical_info;
CREATE TRIGGER age_and_sex_statistical_info_insert_trigger_instance
BEFORE INSERT ON age_and_sex_statistical_info
FOR EACH ROW EXECUTE PROCEDURE age_and_sex_statistical_info_insert_trigger();

CREATE OR REPLACE FUNCTION age_and_sex_statistical_info_detail_insert_trigger() RETURNS TRIGGER AS
$$
	DECLARE
		parent text := 'age_and_sex_statistical_info_detail';
		part text;
		t_cur timestamp;
		t_beg timestamp;
		t_end timestamp;
	BEGIN
		part := parent || '_' || to_char(new.send_time, 'YYMMDD');

		IF NOT EXISTS (
			select * from information_schema.tables
			where table_name = part
		) THEN
			t_cur := new.send_time;
			t_beg := to_timestamp(to_char(t_cur, 'YYYY-MM-DD 00:00:00'),
			'YYYY-MM-DD HH24:MI:SS');
			t_end := t_beg + '1 days';

			EXECUTE 'CREATE TABLE ' ||part|| ' (LIKE ' ||parent|| '
		    	INCLUDING INDEXES INCLUDING DEFAULTS INCLUDING CONSTRAINTS, ' ||
				 'CHECK (' ||quote_literal(t_beg)|| ' <= send_time AND send_time < '
		    	|| quote_literal(t_end)|| ')'
				|| ') INHERITS (' ||parent|| ')';

			EXECUTE 'ALTER TABLE ' || part || ' SET (autovacuum_enabled = true, toast.autovacuum_enabled = true)';
		END IF;
		EXECUTE 'INSERT INTO ' || part || ' VALUES(($1).*)' USING new;
		RETURN NULL;
	EXCEPTION WHEN duplicate_table THEN
		EXECUTE 'INSERT INTO ' || part || ' VALUES(($1).*)' USING new;
		RETURN NULL;
    END
$$ language plpgsql;

DROP TRIGGER IF EXISTS age_and_sex_statistical_info_detail_insert_trigger_instance ON age_and_sex_statistical_info_detail;
CREATE TRIGGER age_and_sex_statistical_info_detail_insert_trigger_instance
BEFORE INSERT ON age_and_sex_statistical_info_detail
FOR EACH ROW EXECUTE PROCEDURE age_and_sex_statistical_info_detail_insert_trigger();
